Index: trunk/psModules/src/detrend/pmFringeStats.h
===================================================================
--- trunk/psModules/src/detrend/pmFringeStats.h	(revision 9855)
+++ trunk/psModules/src/detrend/pmFringeStats.h	(revision 9951)
@@ -8,6 +8,6 @@
 /// @author Paul Price, IfA
 ///
-/// @version $Revision: 1.10 $ $Name: not supported by cvs2svn $
-/// @date $Date: 2006-11-04 02:34:30 $
+/// @version $Revision: 1.11 $ $Name: not supported by cvs2svn $
+/// @date $Date: 2006-11-13 22:19:52 $
 ///
 /// Copyright 2004-2006 Institute for Astronomy, University of Hawaii
@@ -78,6 +78,4 @@
                                         );
 
-
-
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
 // pmFringeStats
@@ -147,24 +145,21 @@
 /// Write an array of fringes measurements to a FITS table.
 ///
-/// Writes an array of fringe measurements for the same FPA component as a FITS table.  The array of fringe
-/// statistics must all use the same fringe regions (or there is no point in storing them all together).  The
-/// header is supplemented with scalar values dX, dY, nX and nY (as PSFRNGDX, PSFRNGDY, PSFRNGNX, PSFRNGNY)
-/// from the fringe regions, while the fringe coordinates and mask are written as a FITS table (as x, y,
-/// mask, f, df; f and df are vectors).
-bool pmFringesWriteFits(psFits *fits,    ///< FITS file to which to write
-                        psMetadata *header, ///< Header, or NULL
-                        const psArray *fringes, ///< Array of pmFringeStats, all for the same pmFringeRegion
-                        const char *extname ///< Extension name for table
+/// Writes an array of fringe measurements for a cell as a FITS table in the analysis metadata.  The array of
+/// fringe statistics must all use the same fringe regions (or there is no point in storing them all
+/// together).  The header is supplemented with scalar values dX, dY, nX and nY (as PSFRNGDX, PSFRNGDY,
+/// PSFRNGNX, PSFRNGNY) from the fringe regions, while the fringe coordinates and mask are written as a FITS
+/// table (as x, y, mask, f, df; f and df are vectors).
+bool pmFringesFormat(pmCell *cell,   ///< Cell for which to write
+                     psMetadata *header, ///< Header, or NULL
+                     const psArray *fringes ///< Array of pmFringeStats, all for the same pmFringeRegion
+                    );
+
+/// Parses an array of fringes measurements from a FITS table.
+///
+/// The fringes for the cell are read from the FITS table in the analysis metadata.  The table provides the
+/// region and the (possibly multiple) fringe statistics for that region.  The current extension is used if
+/// the extension name is not provided.
+psArray *pmFringesParse(pmCell *cell ///< Cell for which to read fringes
                        );
-
-/// Reads an array of fringes measurements from a FITS table.
-///
-/// The fringes are read from the FITS file, at the given extension name.  The table provides the region and
-/// the (possibly multiple) fringe statistics for that region.  The current extension is used if the extension
-/// name is not provided.
-psArray *pmFringesReadFits(psMetadata *header, ///< Header to read, or NULL
-                           psFits *fits,///< FITS file from which to read
-                           const char *extname ///< Extension name to read, or NULL
-                          );
 
 
